Returns a list of global constants used throughout the package.
Examples
if (FALSE) { # \dontrun{
globals <- get_STID_globals()
print(globals$supported_formats)
} # }
Returns a list of global constants used throughout the package.
if (FALSE) { # \dontrun{
globals <- get_STID_globals()
print(globals$supported_formats)
} # }