Retrieve sample-specific thresholds from previous analyses
Source:R/SpotDetect.R
GetSapThreshold.RdThis function retrieves stored threshold information from previous SpotDetect analyses (both gene and gene set based)
Usage
GetSapThreshold(STID_obj, meta_key, ...)
# S3 method for class 'STID'
GetSapThreshold(STID_obj = NULL, meta_key = NULL, ...)Value
A list containing threshold information for each requested metadata key, with components 'stat' and 'threshold'
Examples
if (FALSE) { # \dontrun{
# Retrieve thresholds from previous analyses
thresholds <- GetSapThreshold(
STID_obj = STID_object,
meta_key = c("M1_SpotDetect_Gene_20240101", "M1_SpotDetect_Geneset_20240101")
)
} # }