The STID (Spatial Transcriptomics toolkit for Infectious Diseases) object extends the Seurat class to add specialized functionality for analyzing infection and spatial transcriptomics data. It inherits all functionality from Seurat objects while adding additional slots for tracking infection-related analyses.
Slots
STID_analysisAn
STID_analysisobject containing all infection-specific analysis results and metadataassaysA list of assays for this project (inherited from Seurat)
meta.dataContains meta-information about each cell (inherited from Seurat)
active.assayName of the active, or default, assay (inherited from Seurat)
active.identThe active cluster identity (inherited from Seurat)
graphsA list of
Graphobjects (inherited from Seurat)neighborsNeighbor graphs (inherited from Seurat)
reductionsA list of dimensional reduction objects (inherited from Seurat)
imagesA list of spatial image objects (inherited from Seurat)
project.nameName of the project (inherited from Seurat)
miscA list of miscellaneous information (inherited from Seurat)
versionVersion of Seurat this object was built under (inherited from Seurat)
commandsA list of logged commands (inherited from Seurat)
toolsA list of miscellaneous data generated by other tools (inherited from Seurat)
See also
Other STID-classes:
STID_analysis-class
Examples
if (FALSE) { # \dontrun{
# Create an STID object from a Seurat object
ist_obj <- as.STID(
seurat_obj = seurat_object,
samp_colnm = "sample_id",
celltype_colnm = "cell_type",
host_org = "human",
pathogen_grp = "virus",
pathogen_org = "SARS-CoV-2",
data_format = "StereoSeq"
)
} # }